<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Output;

// Import framework stuff
use Org\Mxchange\CoreFramework\Bootstrap\FrameworkBootstrap;
use Org\Mxchange\CoreFramework\Generic\UnsupportedOperationException;
use Org\Mxchange\CoreFramework\Output\BaseOutput;
use Org\Mxchange\CoreFramework\Stream\Output\OutputStreamer;

/**
 * This class simply puts text without any HTML code out. This class is suiable
 * for console output
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2022 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ConsoleOutput extends BaseOutput implements OutputStreamer {
	/**
	 * The instance for the singleton design pattern
	 */
	private static $consoleInstance = NULL;

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Create a new web output system and set the content type
	 *
	 * @param	$contentType	A valid content-type
	 * @return	$debugInstance	An instance of this middleware class
	 */
	public static final function createConsoleOutput (string $contentType) {
		// Cast the content-type to string
		$contentType = trim($contentType);

		// Get instance
		self::$consoleInstance = new ConsoleOutput();

		// Set the content type
		// @TODO Need to rewrite this to $requestInstance->addHeader()
		if (!empty($contentType)) {
			@header(sprintf('Content-type: %s',
				$contentType
			));
		}

		// Return instance
		return self::$consoleInstance;
	}

	/**
	 * Getter for an instance of this class
	 *
	 * @return	$consoleInstance	An instance of this class
	 */
	public static final function getInstance() {
		// Is the self-instance already set?
		if (is_null(self::$consoleInstance)) {
			$contentType = FrameworkBootstrap::getConfigurationInstance()->getConfigEntry('web_content_type');
			self::$consoleInstance = ConsoleOutput::createConsoleOutput($contentType);
		}

		// Return the instance
		return self::$consoleInstance;
	}

	/**
	 * Output the code
	 *
	 * @param	$outStream	Something we shall sent to the console
	 * @param	$stripTags	Whether HTML tags shall be stripped out
	 * @return	void
	 */
	public final function output (string $outStream = '', bool $stripTags = false) {
		print trim($outStream) . PHP_EOL;
	}

}
